<!DOCTYPE TS><TS>
<context>
    <name>QObject</name>
    <message>
        <source>Null</source>
        <comment>Type name</comment>
        <translation>Null</translation>
    </message>
    <message>
        <source>Bool</source>
        <comment>Type name</comment>
        <translation>Bool</translation>
    </message>
    <message>
        <source>Int</source>
        <comment>Type name</comment>
        <translation>Int</translation>
    </message>
    <message>
        <source>Real</source>
        <comment>Type name</comment>
        <translation>Real</translation>
    </message>
    <message>
        <source>String</source>
        <comment>Type name</comment>
        <translation>String</translation>
    </message>
    <message>
        <source>Ref</source>
        <comment>Type name</comment>
        <translation>Ref</translation>
    </message>
    <message>
        <source>Stream</source>
        <comment>Type name</comment>
        <translation>Stream</translation>
    </message>
    <message>
        <source>DebugCmd</source>
        <comment>Type name</comment>
        <translation>DebugCmd</translation>
    </message>
    <message>
        <source>DebugError</source>
        <comment>Type name</comment>
        <translation>DebugError</translation>
    </message>
    <message>
        <source>DebugEOF</source>
        <comment>Type name</comment>
        <translation>DebugEOF</translation>
    </message>
    <message>
        <source>DebugNone</source>
        <comment>Type name</comment>
        <translation>DebugNone</translation>
    </message>
    <message>
        <source>&lt;no name&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fatal Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Options: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print help and exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print version and exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid commandline option : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop processing options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF files (*.pdf)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open file ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save file as ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <comment>Type name</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Array</source>
        <comment>Type name</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dict</source>
        <comment>Type name</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid %1 in config:
Name: %2
Data: %3
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expected: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missing item in config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>menu definition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>menu item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2 or more parameters in item definition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>toolbar item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4 parameters in item definition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>toolbar definition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cycle in menu detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Catalog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Menu items list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add and c&amp;lose</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stream</source>
        <translation type="unfinished">Stream</translation>
    </message>
    <message>
        <source>Parameter missing for option : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set debug messages verbosity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(n = -1 .. 5)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add object</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>label item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Content Stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>page</source>
        <comment>1</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pages</source>
        <comment>2-4</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pages</source>
        <comment>5+</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>parameter</source>
        <comment>1</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>parameters</source>
        <comment>2-4</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>parameters</source>
        <comment>5+</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>child</source>
        <comment>1</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>childs</source>
        <comment>2-4</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>childs</source>
        <comment>5+</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pick a file ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New revision of document created</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error occured while loading file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image was not saved!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Changed revision to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning: This document is linearized PDF!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show all operators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show only text operators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Showing all</source>
        <comment>mode</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Showing text. op.</source>
        <comment>mode</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Null pointer access in </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show only font operators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Showing font. op.</source>
        <comment>mode</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning: This document is encrypted!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encryption filter:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No page selected!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left upper corner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>x position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>y position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right bottom corner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set font properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set line dash style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set line width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add system font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extract text from page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page rotated.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MediaBox changed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No page or operator selected!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selected operator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is not</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>suitable for colour setting.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line width changed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dash pattern changed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>text operator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font changed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add system fonts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Avaliable system fonts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select system Type1 font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System font added.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text on page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text extracted from page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page text displayed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operator must be</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No preceding font operator found...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid operand type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This option is not supported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show only graphical operators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set relative position of a single operator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set relative position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set page tranformation matrix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change page rectangle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page metrics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change effect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Global change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change line dash pattern</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line dashing patterns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Solid line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slightly dashed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dot and dashed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not valid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Only text operators allowed!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add page transformation matrix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change page transformation matrix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page transformation matrix description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page transformation description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select which transformations to use</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translate (shift) page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skew page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page skewing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid number supplied.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page transformation matrix changed to </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not find text positioning.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change relative text operator position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operator position changed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Showing graphic. op.</source>
        <comment>mode</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>element</source>
        <comment>1</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>elements</source>
        <comment>2-4</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>elements</source>
        <comment>5+</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>item</source>
        <comment>1</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>items</source>
        <comment>2-4</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>items</source>
        <comment>5+</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change relative text position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save page as image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save selected area as image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add item to dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add element to array</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Annotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line was drawn.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encrypted content will show up as garbage and many operations will be impossible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rect was drawn.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw rect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set values</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Relative operator position (this is not absolute position)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Relative operator position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>bytes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>input file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>output file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Input file must exist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Output file must not exist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is expecting two parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Input file &apos;%1&apos; does not exist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Output file &apos;%1&apos; already exist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delinearized</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Available functions:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No function found matching &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Too many function found matching &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Matching functions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>First parameter is name of function to invoke (case insensitive) or its unambiguous part.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rest of parameters are passed to invoked function.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Run in commandline mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Run script from script path or current directory if not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Run script from current directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Evaluate script code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>function name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>function parameter(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>option(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>files(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please see the pdf specification for details.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text on a page.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shortcut for</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Must define color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>r,g,b must be number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>r,g,b must be from 0 to 255</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>complex item is not shown</source>
        <comment>1</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>complex items are not shown</source>
        <comment>2-4</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>complex items are not shown</source>
        <comment>5+</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>out of range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find what</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On currently viewed page only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nothing was found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Overwrite?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File called &quot;%1&quot; already exists. Do you want to overwrite it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delinearization failed!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Colour changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>for</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>operators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Annotations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Input and output files must be different</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>changeable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>suitable for line width change.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>suitable for dash style change.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delinearize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 added to page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operator %1 is not changeable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X and Y position must be a number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dictionary has no type!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maybe bad stream!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is requirement for %2, but not found for it !</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>For child %1 of %2 is requirement %3 subchild, but has %4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operator &apos;%1&apos; should have 1 parameter, but has %2 !</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operator &apos;%1&apos; should have %2 parameters, but has %3 !</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page parameter must be defined!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operator cm must have array with 6 numbers as parameter!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Matrix is in bad state !</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document is read-only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move one level up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move one level down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid operation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>xml files (*.xml)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save as text file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text saved to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font size (in points)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line width (in points)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use &apos;%1 --help&apos; to see list of commandline options and their parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saved as</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to open file: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not implemented: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply from page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>How many pages</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>annotation_type</name>
    <message>
        <source>Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FreeText</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Square</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Circle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polygon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PolyLine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Highlight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Underline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Squiggly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>StrikeOut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stamp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Caret</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ink</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Popup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fileattachement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Movie</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Widget</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Printermark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trapnet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3D</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::AboutWindow</name>
    <message>
        <source>Homepage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About program</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Compiled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This program is distributed under terms of GNU GPL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Free program for PDF document manipulation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Project page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Using Qt %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>, QSA %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::AddItemDialog</name>
    <message>
        <source>Add object</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New empty Dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New empty Array</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Property name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Entered property is not valid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name of new property must be specified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Property &apos;%1&apos; added to dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Property added to end of array</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type and value of new object</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No object type selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Property &apos;%1&apos; already exist as %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reference target does not exist!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add to position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Append to end</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Property added to position %1 in array</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Array index %1 out of range</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::AnnotDialog</name>
    <message>
        <source>Add new annotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Annotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Icon &amp;Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NewParagraph</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Note</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paragraph</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;State</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unmarked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>State &amp;Model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Review</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Text Annotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Destination</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Highlight mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>N - None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I - Invert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>O - Outline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>P - Push</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Link Annotation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::Base</name>
    <message>
        <source>Error running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Script not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No init script found - check your configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Looked for</source>
        <comment>scripts</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::BaseCore</name>
    <message>
        <source>Null pointer access in </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid object given for parameter %1 in </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expected</source>
        <comment>object type</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Got</source>
        <comment>object type</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error in callback handler: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exception in callback handler: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown exception in script occured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In script</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exception in </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::BaseGUI</name>
    <message>
        <source>No document opened</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::ColorTool</name>
    <message>
        <source>Choose color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Foreground</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Background</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::HelpWindow</name>
    <message>
        <source>help</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::MergeDialog</name>
    <message>
        <source>Insert pages from another document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open file with pages to be inserted</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::MultiTreeWindow</name>
    <message>
        <source>Tree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close current tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document tree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch to ...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::OptionWindow</name>
    <message>
        <source>options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Advanced mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Icon Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Object tree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Object dictionaries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Outlines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Graphic objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Annotations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Simple Objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show return value of executed scripts in console</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>History file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max. lines in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toolbars</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Look and Feel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can specify overall visual style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember path of last opened/saved file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Turning on advanced mode will allow more powerful (but also more dangerous) changes to edited document.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Note&lt;/b&gt;: changing Advanced mode will affect only newly opened files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paths</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can use environment variables (for example $HOME) in settings on this page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Note&lt;/b&gt;: changing Icon Path will take effect on next program start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Console log file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>These objects will be shown in the object tree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>These toolbars will be shown:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show errors from event handlers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Content Streams</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show command editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show command line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Editable command line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Script Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scripts to run on start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can set fonts used in application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Console font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Icon theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use big icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show hidden properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow editing read-only properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Commandline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Commandline options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Options affecting object tree and property editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort dictionary items alphabetically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>History options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Statusbar font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show return value also for complex types
(possibly long output)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Note&lt;/b&gt;: changing icon theme will take effect on next program start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Character encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length units</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Initial focus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This will specify which part of editor window will receive keyboard focus when new window is opened</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::PageSpace</name>
    <message>
        <source>Save as image ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 of %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::PdfEditWindow</name>
    <message>
        <source>Current file is not saved. Do you want to save it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loaded file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error while loading document </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown error while loading document </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No document to save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>viewing revision</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document is in read-only mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown error occured while saving document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Linearized PDF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encrypted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selected operators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selected annotations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saving not implemented:
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error occured while saving copy:
%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::Property</name>
    <message>
        <source>Read only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hidden</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::PropertyEditor</name>
    <message>
        <source>No object selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This type of object does not have any properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This operator does not have any directly editable parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This %1 is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dictionary</source>
        <comment>property type</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This %1 does not have any directly editable properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>stream</source>
        <comment>property type</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This array is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This array does not have any directly editable elements</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This operator does not have any parameters</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::QSPage</name>
    <message>
        <source>Invalid operation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Out of range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown exception</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::QSPdf</name>
    <message>
        <source>Page not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document is in read-only mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown error occured while saving document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to save:
%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::RefPropertyDialog</name>
    <message>
        <source>Reference target</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose target for indirect reference</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Object number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Generation number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reference target is not valid</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::RevisionTool</name>
    <message>
        <source>No revisions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Revision: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>bytes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Linearized PDF</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::SelectPagesDialog</name>
    <message>
        <source>Convert pdf to xml</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::Settings</name>
    <message>
        <source>Main Toolbar</source>
        <comment>MainToolbar</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <comment>fload</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <comment>fsave</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <comment>opts</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main menu</source>
        <comment>MainMenu</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New &amp;Window</source>
        <comment>neww</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <comment>quit</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page Toolbar</source>
        <comment>PageToolbar</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add object</source>
        <comment>treeAdditem</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete object</source>
        <comment>treeDelitem</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;About</source>
        <comment>help_about</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <comment>help_index</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>First Page</source>
        <comment>firstpage</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prev Page</source>
        <comment>prevpage</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next Page</source>
        <comment>nextpage</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Page</source>
        <comment>lastpage</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Revision Toolbar</source>
        <comment>RevisionToolbar</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Revisions</source>
        <comment>revlabel</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate page 270 degrees</source>
        <comment>rot-90</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate page 90 degrees</source>
        <comment>rot90</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save &amp;copy...</source>
        <comment>fsavecopy</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Page</source>
        <comment>pagemenu</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save page as image...</source>
        <comment>savepage</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show all operators in stream</source>
        <comment>streamAll</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show only text operators in stream</source>
        <comment>streamText</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show only font operators in stream</source>
        <comment>streamFont</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operator Toolbar</source>
        <comment>OperatorToolbar</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit page metrics</source>
        <comment>editPageMediaBox</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close Window</source>
        <comment>closew</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show/Hide &amp;commandline</source>
        <comment>hideCmd</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add system font to page</source>
        <comment>addSystemFont</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extract text from page</source>
        <comment>pagetext</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;out</source>
        <comment>zoom_out</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;in</source>
        <comment>zoom_in</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show only graphical operators in stream</source>
        <comment>streamGfx</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selection mode Toolbar</source>
        <comment>SelectionModeToolbar</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select all objects</source>
        <comment>selectAllObjects</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select text</source>
        <comment>selectText</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;File</source>
        <comment>filemenu</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save new &amp;revision</source>
        <comment>fsaverev</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;View</source>
        <comment>showmenu</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show/Hide &amp;property editor</source>
        <comment>hideProp</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show/Hide object &amp;tree</source>
        <comment>hideTree</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <comment>toolsmenu</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <comment>editopersmenu</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set color</source>
        <comment>opsetcolor</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set font</source>
        <comment>opsetfont</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set line dash style</source>
        <comment>opsetdash</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set line width</source>
        <comment>opsetlinewidth</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <comment>helpmenu</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set page transformation matrix</source>
        <comment>setpagetm</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set relative position of operator</source>
        <comment>opsetposop</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change relative position</source>
        <comment>opsetpos</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show/Hide &amp;status bar</source>
        <comment>hideStatus</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add text</source>
        <comment>addtext</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw line</source>
        <comment>drawlinee</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw rectangle</source>
        <comment>drawrecte</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select annotations</source>
        <comment>selectAnnot</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Toolbar</source>
        <comment>TextToolBar</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Find text</source>
        <comment>searchText</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Insert Pages from other document</source>
        <comment>mergeDoc</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw Toolbar</source>
        <comment>DrawToolbar</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move page up</source>
        <comment>pageMoveUp</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move page down</source>
        <comment>pageMoveDown</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove page</source>
        <comment>pageRemove</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Highlighting text</source>
        <comment>highlightingtext</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select graphical operators</source>
        <comment>selectGraphical</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TreeView Toolbar</source>
        <comment>TreeViewToolbar</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dynamic Toolbar</source>
        <comment>DynamicToolBar</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Strike through</source>
        <comment>striketrough</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw arrow</source>
        <comment>drawarrowe</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PageRider Toolbar</source>
        <comment>PageRiderToolbar</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save as text...</source>
        <comment>fsaveastext</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reload Page (show changes)</source>
        <comment>reloadpage</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::TreeItemPdf</name>
    <message>
        <source>Pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Outlines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::TreeWindow</name>
    <message>
        <source>Object</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Data</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::Units</name>
    <message>
        <source>point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>inch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>inches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>hands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>hand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>foot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>feet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>yard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>yards</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>rod</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>rods</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pole</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>poles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>perch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>perches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fathom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fathoms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>chain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>chains</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>furlong</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>furlongs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>mile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>miles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>land</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>league</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>leagues</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>nautical mile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>nautical miles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pt : point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>in : inch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>hand : hand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ft : foot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>li : link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>yd : yard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>rd : rod (pole, perch)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ch : chain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>mi : mile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>land : land (league)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>m : meter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ym : yottameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zm : zettameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Em : exameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pm : petameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tm : terameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gm : gigameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mm : megameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>km : kilometer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>hm : hectometer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dam : decameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dm : decimeter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cm : centimeter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>mm : millimeter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>um : micrometer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>nm : nanometer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pm : picometer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fm : femtometer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>am : attometer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zm : zeptometer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ym : yoctometer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A : angstrom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>astronomical unit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>astronomical units</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AU : astronomical unit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>light year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>light years</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ly : light year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>parsec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pc : parsec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>mil : milli-inch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fm. : fathom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fur. : furlong</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cable : cable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>n.m. : nautical mile</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
